@@ -1,4 +1,4 @@
-/* Copyright 2010--2017 The Tor Project
+/* Copyright 2010--2018 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.collector.bridgedescs;
@@ -34,6 +34,7 @@ import java.text.ParseException;
 import java.text.SimpleDateFormat;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.SortedMap;
@@ -166,9 +167,9 @@ public class SanitizedBridgesWriter extends CollecTorMain {
               && line.length() != ("yyyy-MM,".length() + 83 * 2))
               || parts.length != 2) {
             logger.warn("Invalid line in bridge-ip-secrets file "
-                + "starting with '" + line.substring(0, 7) + "'! "
+                + "starting with '{}'! "
                 + "Not calculating any IP address hashes in this "
-                + "execution!");
+                + "execution!", line.substring(0, 7));
             this.persistenceProblemWithSecrets = true;
             break;
           }
@@ -177,19 +178,16 @@ public class SanitizedBridgesWriter extends CollecTorMain {
           this.secretsForHashingIpAddresses.put(month, secret);
         }
         if (!this.persistenceProblemWithSecrets) {
-          logger.debug("Read "
-              + this.secretsForHashingIpAddresses.size() + " secrets for "
-              + "hashing bridge IP addresses.");
+          logger.debug("Read {} secrets for hashing bridge IP addresses.",
+              this.secretsForHashingIpAddresses.size());
         }
       } catch (DecoderException e) {
-        logger.warn("Failed to decode hex string in "
-            + this.bridgeIpSecretsFile + "! Not calculating any IP "
-            + "address hashes in this execution!", e);
+        logger.warn("Failed to decode hex string in {}! Not calculating any IP "
+            + "address hashes in this execution!", this.bridgeIpSecretsFile, e);
         this.persistenceProblemWithSecrets = true;
       } catch (IOException e) {
-        logger.warn("Failed to read "
-            + this.bridgeIpSecretsFile + "! Not calculating any IP "
-            + "address hashes in this execution!", e);
+        logger.warn("Failed to read {}! Not calculating any IP "
+            + "address hashes in this execution!", this.bridgeIpSecretsFile, e);
         this.persistenceProblemWithSecrets = true;
       }
     }
@@ -460,11 +458,11 @@ public class SanitizedBridgesWriter extends CollecTorMain {
     }
 
     /* Parse the given network status line by line. */
-    StringBuilder header = new StringBuilder();
+    DescriptorBuilder header = new DescriptorBuilder();
     boolean includesFingerprintLine = false;
     SortedMap<String, String> scrubbedLines = new TreeMap<>();
     try {
-      StringBuilder scrubbed = new StringBuilder();
+      DescriptorBuilder scrubbed = new DescriptorBuilder();
       BufferedReader br = new BufferedReader(new StringReader(new String(
           data, "US-ASCII")));
       String line = null;
@@ -482,18 +480,18 @@ public class SanitizedBridgesWriter extends CollecTorMain {
 
         /* Additional header lines don't have to be cleaned up. */
         } else if (line.startsWith("flag-thresholds ")) {
-          header.append(line + "\n");
+          header.append(line).newLine();
 
         /* The authority fingerprint in the "fingerprint" line can go in
          * unscrubbed. */
         } else if (line.startsWith("fingerprint ")) {
           if (!("fingerprint " + authorityFingerprint).equals(line)) {
             logger.warn("Mismatch between authority fingerprint expected from "
-                + "file name (" + authorityFingerprint + ") and parsed from "
-                + "\"fingerprint\" line (\"" + line + "\").");
+                + "file name ({}) and parsed from \"fingerprint\" "
+                + "line (\"{}\").", authorityFingerprint, line);
             return;
           }
-          header.append(line + "\n");
+          header.append(line).newLine();
           includesFingerprintLine = true;
 
         /* r lines contain sensitive information that needs to be removed
@@ -501,22 +499,22 @@ public class SanitizedBridgesWriter extends CollecTorMain {
         } else if (line.startsWith("r ")) {
 
           /* Clear buffer from previously scrubbed lines. */
-          if (scrubbed.length() > 0) {
+          if (scrubbed.hasContent()) {
             String scrubbedLine = scrubbed.toString();
             scrubbedLines.put(hashedBridgeIdentityHex, scrubbedLine);
-            scrubbed = new StringBuilder();
+            scrubbed = new DescriptorBuilder();
           }
 
           /* Parse the relevant parts of this r line. */
           String[] parts = line.split(" ");
           if (parts.length < 9) {
-            logger.warn("Illegal line '" + line + "' in bridge network "
-                + "status.  Skipping descriptor.");
+            logger.warn("Illegal line '{}' in bridge network "
+                + "status.  Skipping descriptor.", line);
             return;
           }
           if (!Base64.isBase64(parts[2])) {
-            logger.warn("Illegal base64 character in r line '" + parts[2]
-                + "'.  Skipping descriptor.");
+            logger.warn("Illegal base64 character in r line '{}'.  "
+                + "Skipping descriptor.", parts[2]);
             return;
           }
           fingerprintBytes = Base64.decodeBase64(parts[2] + "==");
@@ -551,11 +549,13 @@ public class SanitizedBridgesWriter extends CollecTorMain {
               fingerprintBytes, descPublicationTime);
           String scrubbedDirPort = this.scrubTcpPort(dirPort,
               fingerprintBytes, descPublicationTime);
-          scrubbed.append("r " + nickname + " "
-              + hashedBridgeIdentityBase64 + " "
-              + hashedDescriptorIdentifier + " " + descPublicationTime
-              + " " + scrubbedAddress + " " + scrubbedOrPort + " "
-              + scrubbedDirPort + "\n");
+          scrubbed.append("r ").append(nickname).space()
+              .append(hashedBridgeIdentityBase64).space()
+              .append(hashedDescriptorIdentifier).space()
+              .append(descPublicationTime).space()
+              .append(scrubbedAddress).space()
+              .append(scrubbedOrPort).space()
+              .append(scrubbedDirPort).newLine();
 
         /* Sanitize any addresses in a lines using the fingerprint and
          * descriptor publication time from the previous r line. */
@@ -564,35 +564,35 @@ public class SanitizedBridgesWriter extends CollecTorMain {
               line.substring("a ".length()), fingerprintBytes,
               descPublicationTime);
           if (scrubbedOrAddress != null) {
-            scrubbed.append("a " + scrubbedOrAddress + "\n");
+            scrubbed.append("a ").append(scrubbedOrAddress).newLine();
           } else {
-            logger.warn("Invalid address in line '" + line
-                + "' in bridge network status.  Skipping line!");
+            logger.warn("Invalid address in line '{}' "
+                + "in bridge network status.  Skipping line!", line);
           }
 
         /* Nothing special about s, w, and p lines; just copy them. */
         } else if (line.startsWith("s ") || line.equals("s")
             || line.startsWith("w ") || line.equals("w")
             || line.startsWith("p ") || line.equals("p")) {
-          scrubbed.append(line + "\n");
+          scrubbed.append(line).newLine();
 
         /* There should be nothing else but r, a, w, p, and s lines in the
          * network status.  If there is, we should probably learn before
          * writing anything to the sanitized descriptors. */
         } else {
-          logger.debug("Unknown line '" + line + "' in bridge "
-              + "network status. Not writing to disk!");
+          logger.debug("Unknown line '{}' in bridge "
+              + "network status. Not writing to disk!", line);
           return;
         }
       }
       br.close();
-      if (scrubbed.length() > 0) {
+      if (scrubbed.hasContent()) {
         String scrubbedLine = scrubbed.toString();
         scrubbedLines.put(hashedBridgeIdentityHex, scrubbedLine);
-        scrubbed = new StringBuilder();
+        scrubbed = new DescriptorBuilder();
       }
       if (!includesFingerprintLine) {
-        header.append("fingerprint ").append(authorityFingerprint).append("\n");
+        header.append("fingerprint ").append(authorityFingerprint).newLine();
       }
 
       /* Check if we can tell from the descriptor publication times
@@ -601,25 +601,23 @@ public class SanitizedBridgesWriter extends CollecTorMain {
           "yyyy-MM-dd HH:mm:ss");
       formatter.setTimeZone(TimeZone.getTimeZone("UTC"));
       if (null == mostRecentDescPublished) {
-        logger.warn("The bridge network status published at " + publicationTime
+        logger.warn("The bridge network status published at {}"
             + " does not contain a single entry. Please ask the bridge "
-            + "authority operator to check!");
+            + "authority operator to check!", publicationTime);
       } else if (formatter.parse(publicationTime).getTime()
           - formatter.parse(mostRecentDescPublished).getTime()
           > 60L * 60L * 1000L) {
         logger.warn("The most recent descriptor in the bridge "
-            + "network status published at " + publicationTime + " was "
-            + "published at " + mostRecentDescPublished + " which is "
+            + "network status published at {} was published at {} which is "
             + "more than 1 hour before the status. This is a sign for "
-            + "the status being stale. Please check!");
+            + "the status being stale. Please check!",
+            publicationTime, mostRecentDescPublished);
       }
     } catch (ParseException e) {
-      logger.warn("Could not parse timestamp in "
-          + "bridge network status.", e);
+      logger.warn("Could not parse timestamp in bridge network status.", e);
       return;
     } catch (IOException e) {
-      logger.warn("Could not parse bridge network "
-          + "status.", e);
+      logger.warn("Could not parse bridge network status.", e);
       return;
     }
 
@@ -671,23 +669,19 @@ public class SanitizedBridgesWriter extends CollecTorMain {
     }
 
     /* Parse descriptor to generate a sanitized version. */
-    String scrubbedDesc = null;
+    String address = null;
     String published = null;
+    byte[] fingerprintBytes = null;
+    StringBuilder scrubbedAddress = null;
+    Map<StringBuilder, String> scrubbedTcpPorts = new HashMap<>();
+    Map<StringBuilder, String> scrubbedIpAddressesAndTcpPorts = new HashMap<>();
     String masterKeyEd25519FromIdentityEd25519 = null;
-    try {
-      BufferedReader br = new BufferedReader(new StringReader(
-          new String(data, "US-ASCII")));
-      StringBuilder scrubbed = new StringBuilder();
-      String line = null;
-      byte[] fingerprintBytes = null;
-      String hashedBridgeIdentity = null;
-      String address = null;
-      String routerLine = null;
-      String scrubbedRouterLine = null;
-      String scrubbedAddress = null;
+    DescriptorBuilder scrubbed = new DescriptorBuilder();
+    try (BufferedReader br = new BufferedReader(new StringReader(
+        new String(data, "US-ASCII")))) {
+      scrubbed.append(Annotation.BridgeServer.toString());
+      String line;
       String masterKeyEd25519 = null;
-      List<String> orAddresses = null;
-      List<String> scrubbedOrAddresses = null;
       boolean skipCrypto = false;
       while ((line = br.readLine()) != null) {
 
@@ -702,19 +696,30 @@ public class SanitizedBridgesWriter extends CollecTorMain {
         } else if (line.startsWith("router ")) {
           String[] parts = line.split(" ");
           if (parts.length != 6) {
-            logger.warn("Invalid router line: '" + line + "'.  Skipping.");
+            logger.warn("Invalid router line: '{}'.  Skipping.", line);
             return;
           }
           address = parts[2];
-          routerLine = line;
+          scrubbedAddress = new StringBuilder();
+          StringBuilder scrubbedOrPort = new StringBuilder();
+          scrubbedTcpPorts.put(scrubbedOrPort, parts[3]);
+          StringBuilder scrubbedDirPort = new StringBuilder();
+          scrubbedTcpPorts.put(scrubbedDirPort, parts[4]);
+          StringBuilder scrubbedSocksPort = new StringBuilder();
+          scrubbedTcpPorts.put(scrubbedSocksPort, parts[5]);
+          scrubbed.append("router ").append(parts[1]).space()
+              .append(scrubbedAddress).space()
+              .append(scrubbedOrPort).space()
+              .append(scrubbedDirPort).space()
+              .append(scrubbedSocksPort).newLine();
 
-        /* Store or-address parts in a list and sanitize them when we have
-         * read the fingerprint. */
+        /* Store or-address and sanitize it when we have read the fingerprint
+         * and descriptor publication time. */
         } else if (line.startsWith("or-address ")) {
-          if (orAddresses == null) {
-            orAddresses = new ArrayList<>();
-          }
-          orAddresses.add(line.substring("or-address ".length()));
+          String orAddress = line.substring("or-address ".length());
+          StringBuilder scrubbedOrAddress = new StringBuilder();
+          scrubbedIpAddressesAndTcpPorts.put(scrubbedOrAddress, orAddress);
+          scrubbed.append("or-address ").append(scrubbedOrAddress).newLine();
 
         /* Parse the publication time to see if we're still inside the
          * sanitizing interval. */
@@ -735,21 +740,7 @@ public class SanitizedBridgesWriter extends CollecTorMain {
               this.haveWarnedAboutInterval = true;
             }
           }
-          if (null != fingerprintBytes) {
-            /* We have read both published and fingerprint lines that we need to
-             * scrub the bridge's address which we might need to scrub reject
-             * lines. */
-            try {
-              scrubbedAddress = scrubIpv4Address(address, fingerprintBytes,
-                  published);
-            } catch (IOException e) {
-              /* There's a persistence problem, so we shouldn't scrub more
-               * IP addresses in this execution. */
-              this.persistenceProblemWithSecrets = true;
-              return;
-            }
-          }
-          scrubbed.append(line + "\n");
+          scrubbed.append(line).newLine();
 
         /* Parse the fingerprint to determine the hashed bridge
          * identity. */
@@ -759,91 +750,23 @@ public class SanitizedBridgesWriter extends CollecTorMain {
               ? "opt fingerprint".length() : "fingerprint".length())
               .replaceAll(" ", "").toLowerCase();
           fingerprintBytes = Hex.decodeHex(fingerprint.toCharArray());
-          hashedBridgeIdentity = DigestUtils.sha1Hex(fingerprintBytes)
+          String hashedBridgeIdentity = DigestUtils.sha1Hex(fingerprintBytes)
               .toLowerCase();
-          if (null != published) {
-            /* We have read both published and fingerprint lines that we need to
-             * scrub the bridge's address which we might need to scrub reject
-             * lines. */
-            try {
-              scrubbedAddress = scrubIpv4Address(address, fingerprintBytes,
-                  published);
-            } catch (IOException e) {
-              /* There's a persistence problem, so we shouldn't scrub more
-               * IP addresses in this execution. */
-              this.persistenceProblemWithSecrets = true;
-              return;
-            }
-          }
-          scrubbed.append((line.startsWith("opt ") ? "opt " : "")
-              + "fingerprint");
+          scrubbed.append(line.startsWith("opt ") ? "opt " : "")
+              .append("fingerprint");
           for (int i = 0; i < hashedBridgeIdentity.length() / 4; i++) {
-            scrubbed.append(" " + hashedBridgeIdentity.substring(4 * i,
+            scrubbed.space().append(hashedBridgeIdentity.substring(4 * i,
                 4 * (i + 1)).toUpperCase());
           }
-          scrubbed.append("\n");
+          scrubbed.newLine();
 
         /* Replace the contact line (if present) with a generic one. */
         } else if (line.startsWith("contact ")) {
-          scrubbed.append("contact somebody\n");
+          scrubbed.append("contact somebody").newLine();
 
         /* When we reach the signature, we're done. Write the sanitized
          * descriptor to disk below. */
         } else if (line.startsWith("router-signature")) {
-
-          /* Write the scrubbed "router" line now based on the "router",
-           * "fingerprint", and "published" lines that we read before. Also
-           * scrub any "or-address" lines. */
-          if (null == routerLine || null == fingerprintBytes
-              || null == published) {
-            logger.warn("Missing either of the following lines that are "
-                + "required to sanitize this server bridge descriptor: "
-                + "\"router\", \"fingerprint\", \"published\". Skipping "
-                + "descriptor.");
-            return;
-          }
-          try {
-            if (orAddresses != null) {
-              scrubbedOrAddresses = new ArrayList<>();
-              for (String orAddress : orAddresses) {
-                String scrubbedOrAddress = scrubOrAddress(orAddress,
-                    fingerprintBytes, published);
-                if (scrubbedOrAddress != null) {
-                  scrubbedOrAddresses.add(scrubbedOrAddress);
-                } else {
-                  logger.warn("Invalid address in line "
-                      + "'or-address " + orAddress + "' in bridge server "
-                      + "descriptor.  Skipping line!");
-                }
-              }
-            }
-            String[] routerLineParts = routerLine.split(" ");
-            String nickname = routerLineParts[1];
-            String scrubbedOrPort = this.scrubTcpPort(routerLineParts[3],
-                fingerprintBytes, published);
-            String scrubbedDirPort = this.scrubTcpPort(routerLineParts[4],
-                fingerprintBytes, published);
-            String scrubbedSocksPort = this.scrubTcpPort(
-                routerLineParts[5], fingerprintBytes, published);
-            scrubbedRouterLine = String.format("router %s %s %s %s %s%n",
-                nickname, scrubbedAddress, scrubbedOrPort,
-                scrubbedDirPort, scrubbedSocksPort);
-          } catch (IOException e) {
-            /* There's a persistence problem, so we shouldn't scrub more
-             * IP addresses in this execution. */
-            this.persistenceProblemWithSecrets = true;
-            return;
-          }
-
-          /* Put together the scrubbed descriptor from "router" to the newline
-           * before the original "router-signature" line. */
-          scrubbedDesc = scrubbedRouterLine;
-          if (scrubbedOrAddresses != null) {
-            for (String scrubbedOrAddress : scrubbedOrAddresses) {
-              scrubbedDesc += "or-address " + scrubbedOrAddress + "\n";
-            }
-          }
-          scrubbedDesc += scrubbed.toString();
           break;
 
         /* Replace extra-info digest with the hashed digest of the
@@ -857,32 +780,32 @@ public class SanitizedBridgesWriter extends CollecTorMain {
           }
           if (parts.length > 3) {
             logger.warn("extra-info-digest line contains more arguments than"
-                + "expected: '" + line + "'.  Skipping descriptor.");
+                + "expected: '{}'.  Skipping descriptor.", line);
             return;
           }
-          scrubbed.append("extra-info-digest " + DigestUtils.sha1Hex(
+          scrubbed.append("extra-info-digest ").append(DigestUtils.sha1Hex(
               Hex.decodeHex(parts[1].toCharArray())).toUpperCase());
           if (parts.length > 2) {
             if (!Base64.isBase64(parts[2])) {
-              logger.warn("Illegal base64 character in extra-info-digest line '"
-                  + line + "'.  Skipping descriptor.");
+              logger.warn("Illegal base64 character in extra-info-digest line "
+                  + "'{}'.  Skipping descriptor.", line);
               return;
             }
-            scrubbed.append(" " + Base64.encodeBase64String(
+            scrubbed.space().append(Base64.encodeBase64String(
                 DigestUtils.sha256(Base64.decodeBase64(parts[2])))
                 .replaceAll("=", ""));
           }
-          scrubbed.append("\n");
+          scrubbed.newLine();
 
         /* Possibly sanitize reject lines if they contain the bridge's own
          * IP address. */
         } else if (line.startsWith("reject ")) {
           if (address != null && line.startsWith("reject " + address)) {
-            scrubbed.append("reject " + scrubbedAddress
-                + line.substring("reject ".length() + address.length())
-                + "\n");
+            scrubbed.append("reject ").append(scrubbedAddress)
+                .append(line.substring("reject ".length() + address.length()))
+                .newLine();
           } else {
-            scrubbed.append(line + "\n");
+            scrubbed.append(line).newLine();
           }
 
         /* Extract master-key-ed25519 from identity-ed25519. */
@@ -907,8 +830,8 @@ public class SanitizedBridgesWriter extends CollecTorMain {
               DigestUtils.sha256(Base64.decodeBase64(
               masterKeyEd25519FromIdentityEd25519 + "=")))
               .replaceAll("=", "");
-          scrubbed.append("master-key-ed25519 " + sha256MasterKeyEd25519
-              + "\n");
+          scrubbed.append("master-key-ed25519 ").append(sha256MasterKeyEd25519)
+              .newLine();
           if (masterKeyEd25519 != null && !masterKeyEd25519.equals(
               masterKeyEd25519FromIdentityEd25519)) {
             logger.warn("Mismatch between identity-ed25519 and "
@@ -948,21 +871,21 @@ public class SanitizedBridgesWriter extends CollecTorMain {
             || line.startsWith("ipv6-policy ")
             || line.equals("tunnelled-dir-server")
             || line.startsWith("bridge-distribution-request ")) {
-          scrubbed.append(line + "\n");
+          scrubbed.append(line).newLine();
 
         /* Replace node fingerprints in the family line with their hashes
          * and leave nicknames unchanged. */
         } else if (line.startsWith("family ")) {
-          StringBuilder familyLine = new StringBuilder("family");
+          DescriptorBuilder familyLine = new DescriptorBuilder("family");
           for (String s : line.substring(7).split(" ")) {
             if (s.startsWith("$")) {
-              familyLine.append(" $" + DigestUtils.sha1Hex(Hex.decodeHex(
+              familyLine.append(" $").append(DigestUtils.sha1Hex(Hex.decodeHex(
                   s.substring(1).toCharArray())).toUpperCase());
             } else {
-              familyLine.append(" " + s);
+              familyLine.space().append(s);
             }
           }
-          scrubbed.append(familyLine.toString() + "\n");
+          scrubbed.append(familyLine.toString()).newLine();
 
         /* Skip the purpose line that the bridge authority adds to its
          * cached-descriptors file. */
@@ -991,19 +914,62 @@ public class SanitizedBridgesWriter extends CollecTorMain {
          * that we need to remove or replace for the sanitized descriptor
          * version. */
         } else {
-          logger.warn("Unrecognized line '" + line
-              + "'. Skipping.");
+          logger.warn("Unrecognized line '{}'. Skipping.", line);
           return;
         }
       }
-      br.close();
     } catch (Exception e) {
-      logger.warn("Could not parse server "
-          + "descriptor.", e);
+      logger.warn("Could not parse server descriptor.", e);
       return;
     }
 
-    /* Determine filename of sanitized server descriptor. */
+    /* Sanitize the parts that we couldn't sanitize earlier. */
+    if (null == address || null == fingerprintBytes
+        || null == published) {
+      logger.warn("Missing either of the following lines that are "
+          + "required to sanitize this server bridge descriptor: "
+          + "\"router\", \"fingerprint\", \"published\". Skipping "
+          + "descriptor.");
+      return;
+    }
+    try {
+      String scrubbedAddressString = scrubIpv4Address(address, fingerprintBytes,
+          published);
+      if (null == scrubbedAddressString) {
+        logger.warn("Invalid IP address in \"router\" line in bridge server "
+            + "descriptor. Skipping descriptor.");
+        return;
+      }
+      scrubbedAddress.append(scrubbedAddressString);
+      for (Map.Entry<StringBuilder, String> e
+          : scrubbedIpAddressesAndTcpPorts.entrySet()) {
+        String scrubbedOrAddress = scrubOrAddress(e.getValue(),
+            fingerprintBytes, published);
+        if (null == scrubbedOrAddress) {
+          logger.warn("Invalid IP address or TCP port in \"or-address\" line "
+              + "in bridge server descriptor. Skipping descriptor.");
+          return;
+        }
+        e.getKey().append(scrubbedOrAddress);
+      }
+      for (Map.Entry<StringBuilder, String> e : scrubbedTcpPorts.entrySet()) {
+        String scrubbedTcpPort = scrubTcpPort(e.getValue(), fingerprintBytes,
+            published);
+        if (null == scrubbedTcpPort) {
+          logger.warn("Invalid TCP port in \"router\" line in bridge server "
+              + "descriptor. Skipping descriptor.");
+          return;
+        }
+        e.getKey().append(scrubbedTcpPort);
+      }
+    } catch (IOException exception) {
+      /* There's a persistence problem, so we shouldn't scrub more IP addresses
+       * or TCP ports in this execution. */
+      this.persistenceProblemWithSecrets = true;
+      return;
+    }
+
+    /* Determine digest(s) of sanitized server descriptor. */
     String descriptorDigest = null;
     try {
       String ascii = new String(data, "US-ASCII");
@@ -1020,8 +986,7 @@ public class SanitizedBridgesWriter extends CollecTorMain {
       /* Handle below. */
     }
     if (descriptorDigest == null) {
-      logger.warn("Could not calculate server "
-          + "descriptor digest.");
+      logger.warn("Could not calculate server descriptor digest.");
       return;
     }
     String descriptorDigestSha256Base64 = null;
@@ -1043,11 +1008,18 @@ public class SanitizedBridgesWriter extends CollecTorMain {
         /* Handle below. */
       }
       if (descriptorDigestSha256Base64 == null) {
-        logger.warn("Could not calculate server "
-            + "descriptor SHA256 digest.");
+        logger.warn("Could not calculate server descriptor SHA256 digest.");
         return;
       }
     }
+    if (null != descriptorDigestSha256Base64) {
+      scrubbed.append("router-digest-sha256 ")
+          .append(descriptorDigestSha256Base64).newLine();
+    }
+    scrubbed.append("router-digest ").append(descriptorDigest.toUpperCase())
+        .newLine();
+
+    /* Determine filename of sanitized server descriptor. */
     String dyear = published.substring(0, 4);
     String dmonth = published.substring(5, 7);
     File tarballFile = new File(
@@ -1073,19 +1045,11 @@ public class SanitizedBridgesWriter extends CollecTorMain {
         outputFile.getParentFile().mkdirs();
         BufferedWriter bw = new BufferedWriter(new FileWriter(
             outputFile, appendToFile));
-        bw.write(Annotation.BridgeServer.toString());
-        bw.write(scrubbedDesc);
-        if (descriptorDigestSha256Base64 != null) {
-          bw.write("router-digest-sha256 " + descriptorDigestSha256Base64
-              + "\n");
-        }
-        bw.write("router-digest " + descriptorDigest.toUpperCase()
-            + "\n");
+        bw.write(scrubbed.toString());
         bw.close();
       }
     } catch (ConfigurationException | IOException e) {
-      logger.warn("Could not write sanitized server "
-          + "descriptor to disk.", e);
+      logger.warn("Could not write sanitized server descriptor to disk.", e);
       return;
     }
   }
@@ -1094,27 +1058,26 @@ public class SanitizedBridgesWriter extends CollecTorMain {
       String identityEd25519Base64) {
     byte[] identityEd25519 = Base64.decodeBase64(identityEd25519Base64);
     if (identityEd25519.length < 40) {
-      logger.warn("Invalid length of identity-ed25519 (in "
-          + "bytes): " + identityEd25519.length);
+      logger.warn("Invalid length of identity-ed25519 (in bytes): {}",
+          identityEd25519.length);
     } else if (identityEd25519[0] != 0x01) {
-      logger.warn("Unknown version in identity-ed25519: "
-          + identityEd25519[0]);
+      logger.warn("Unknown version in identity-ed25519: {}",
+          identityEd25519[0]);
     } else if (identityEd25519[1] != 0x04) {
-      logger.warn("Unknown cert type in identity-ed25519: "
-          + identityEd25519[1]);
+      logger.warn("Unknown cert type in identity-ed25519: {}",
+          identityEd25519[1]);
     } else if (identityEd25519[6] != 0x01) {
       logger.warn("Unknown certified key type in "
           + "identity-ed25519: " + identityEd25519[1]);
     } else if (identityEd25519[39] == 0x00) {
       logger.warn("No extensions in identity-ed25519 (which "
-          + "would contain the encoded master-key-ed25519): "
-          + identityEd25519[39]);
+          + "would contain the encoded master-key-ed25519): {}",
+          identityEd25519[39]);
     } else {
       int extensionStart = 40;
       for (int i = 0; i < (int) identityEd25519[39]; i++) {
         if (identityEd25519.length < extensionStart + 4) {
-          logger.warn("Invalid extension with id " + i
-              + " in identity-ed25519.");
+          logger.warn("Invalid extension with id {} in identity-ed25519.", i);
           break;
         }
         int extensionLength = identityEd25519[extensionStart];
@@ -1123,8 +1086,7 @@ public class SanitizedBridgesWriter extends CollecTorMain {
         int extensionType = identityEd25519[extensionStart + 2];
         if (extensionLength == 32 && extensionType == 4) {
           if (identityEd25519.length < extensionStart + 4 + 32) {
-            logger.warn("Invalid extension with id " + i
-                + " in identity-ed25519.");
+            logger.warn("Invalid extension with id {} in identity-ed25519.", i);
             break;
           }
           byte[] masterKeyEd25519 = new byte[32];
@@ -1139,8 +1101,7 @@ public class SanitizedBridgesWriter extends CollecTorMain {
         extensionStart += 4 + extensionLength;
       }
     }
-    logger.warn("Unable to locate master-key-ed25519 in "
-        + "identity-ed25519.");
+    logger.warn("Unable to locate master-key-ed25519 in identity-ed25519.");
     return null;
   }
 
@@ -1160,7 +1121,7 @@ public class SanitizedBridgesWriter extends CollecTorMain {
       BufferedReader br = new BufferedReader(new StringReader(new String(
           data, "US-ASCII")));
       String line = null;
-      StringBuilder scrubbed = null;
+      DescriptorBuilder scrubbed = null;
       String hashedBridgeIdentity = null;
       String masterKeyEd25519 = null;
       while ((line = br.readLine()) != null) {
@@ -1170,18 +1131,18 @@ public class SanitizedBridgesWriter extends CollecTorMain {
         String[] parts = line.split(" ");
         if (line.startsWith("extra-info ")) {
           if (parts.length < 3) {
-            logger.debug("Illegal line in extra-info descriptor: '" + line
-                + "'.  Skipping descriptor.");
+            logger.debug("Illegal line in extra-info descriptor: '{}'.  "
+                + "Skipping descriptor.", line);
             return;
           }
           hashedBridgeIdentity = DigestUtils.sha1Hex(Hex.decodeHex(
               parts[2].toCharArray())).toLowerCase();
-          scrubbed = new StringBuilder("extra-info " + parts[1] + " "
-              + hashedBridgeIdentity.toUpperCase() + "\n");
+          scrubbed = new DescriptorBuilder("extra-info ").append(parts[1])
+            .space().append(hashedBridgeIdentity.toUpperCase()).newLine();
 
         /* Parse the publication time to determine the file name. */
         } else if (line.startsWith("published ")) {
-          scrubbed.append(line + "\n");
+          scrubbed.append(line).newLine();
           published = line.substring("published ".length());
           if (published.compareTo(maxExtraInfoDescriptorPublishedTime)
               > 0) {
@@ -1192,11 +1153,11 @@ public class SanitizedBridgesWriter extends CollecTorMain {
          * name. */
         } else if (line.startsWith("transport ")) {
           if (parts.length < 3) {
-            logger.debug("Illegal line in extra-info descriptor: '"
-                + line + "'.  Skipping descriptor.");
+            logger.debug("Illegal line in extra-info descriptor: '{}'.  "
+                + "Skipping descriptor.", line);
             return;
           }
-          scrubbed.append("transport " + parts[1] + "\n");
+          scrubbed.append("transport ").append(parts[1]).newLine();
 
         /* Skip transport-info lines entirely. */
         } else if (line.startsWith("transport-info ")) {
@@ -1218,8 +1179,8 @@ public class SanitizedBridgesWriter extends CollecTorMain {
               DigestUtils.sha256(Base64.decodeBase64(
               masterKeyEd25519FromIdentityEd25519 + "=")))
               .replaceAll("=", "");
-          scrubbed.append("master-key-ed25519 " + sha256MasterKeyEd25519
-              + "\n");
+          scrubbed.append("master-key-ed25519 ").append(sha256MasterKeyEd25519)
+              .newLine();
           if (masterKeyEd25519 != null && !masterKeyEd25519.equals(
               masterKeyEd25519FromIdentityEd25519)) {
             logger.warn("Mismatch between identity-ed25519 and "
@@ -1254,7 +1215,7 @@ public class SanitizedBridgesWriter extends CollecTorMain {
             || line.startsWith("exit-")
             || line.startsWith("hidserv-")
             || line.startsWith("padding-counts ")) {
-          scrubbed.append(line + "\n");
+          scrubbed.append(line).newLine();
 
         /* When we reach the signature, we're done. Write the sanitized
          * descriptor to disk below. */
@@ -1272,19 +1233,13 @@ public class SanitizedBridgesWriter extends CollecTorMain {
          * that we need to remove or replace for the sanitized descriptor
          * version. */
         } else {
-          logger.warn("Unrecognized line '" + line
-              + "'. Skipping.");
+          logger.warn("Unrecognized line '{}'. Skipping.", line);
           return;
         }
       }
       br.close();
-    } catch (IOException e) {
-      logger.warn("Could not parse extra-info "
-          + "descriptor.", e);
-      return;
-    } catch (DecoderException e) {
-      logger.warn("Could not parse extra-info "
-          + "descriptor.", e);
+    } catch (DecoderException | IOException e) {
+      logger.warn("Could not parse extra-info descriptor.", e);
       return;
     }
 
@@ -1305,8 +1260,7 @@ public class SanitizedBridgesWriter extends CollecTorMain {
       /* Handle below. */
     }
     if (descriptorDigest == null) {
-      logger.warn("Could not calculate extra-info "
-          + "descriptor digest.");
+      logger.warn("Could not calculate extra-info descriptor digest.");
       return;
     }
     String descriptorDigestSha256Base64 = null;
@@ -1403,8 +1357,8 @@ public class SanitizedBridgesWriter extends CollecTorMain {
           }
         }
         bw.close();
-        logger.info("Deleted " + deleted + " secrets that we don't "
-            + "need anymore and kept " + kept + ".");
+        logger.info("Deleted {} secrets that we don't "
+            + "need anymore and kept {}.", deleted, kept);
       } catch (IOException e) {
         logger.warn("Could not store reduced set of "
             + "secrets to disk! This is a bad sign, better check what's "
@@ -1424,8 +1378,8 @@ public class SanitizedBridgesWriter extends CollecTorMain {
       if (maxNetworkStatusPublishedMillis > 0L
           && maxNetworkStatusPublishedMillis < tooOldMillis) {
         logger.warn("The last known bridge network status was "
-            + "published " + maxNetworkStatusPublishedTime + ", which is "
-            + "more than 5:30 hours in the past.");
+            + "published {}, which is more than 5:30 hours in the past.",
+            maxNetworkStatusPublishedTime);
       }
       long maxServerDescriptorPublishedMillis =
           dateTimeFormat.parse(maxServerDescriptorPublishedTime)
@@ -1433,8 +1387,8 @@ public class SanitizedBridgesWriter extends CollecTorMain {
       if (maxServerDescriptorPublishedMillis > 0L
           && maxServerDescriptorPublishedMillis < tooOldMillis) {
         logger.warn("The last known bridge server descriptor was "
-            + "published " + maxServerDescriptorPublishedTime + ", which "
-            + "is more than 5:30 hours in the past.");
+            + "published {}, which is more than 5:30 hours in the past.",
+            maxServerDescriptorPublishedTime);
       }
       long maxExtraInfoDescriptorPublishedMillis =
           dateTimeFormat.parse(maxExtraInfoDescriptorPublishedTime)
@@ -1442,12 +1396,11 @@ public class SanitizedBridgesWriter extends CollecTorMain {
       if (maxExtraInfoDescriptorPublishedMillis > 0L
           && maxExtraInfoDescriptorPublishedMillis < tooOldMillis) {
         logger.warn("The last known bridge extra-info descriptor "
-            + "was published " + maxExtraInfoDescriptorPublishedTime
-            + ", which is more than 5:30 hours in the past.");
+            + "was published {}, which is more than 5:30 hours in the past.",
+            maxExtraInfoDescriptorPublishedTime);
       }
     } catch (ParseException e) {
-      logger.warn("Unable to parse timestamp for "
-          + "stale check.", e);
+      logger.warn("Unable to parse timestamp for stale check.", e);
     }
   }
 
