@@ -1,15 +1,22 @@
-/* Copyright 2010--2016 The Tor Project
+/* Copyright 2010--2018 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.collector.relaydescs;
 
+import org.torproject.collector.conf.Annotation;
 import org.torproject.collector.conf.Configuration;
 import org.torproject.collector.conf.ConfigurationException;
 import org.torproject.collector.conf.Key;
+import org.torproject.collector.conf.SourceType;
 import org.torproject.collector.cron.CollecTorMain;
-import org.torproject.descriptor.DescriptorParseException;
+import org.torproject.descriptor.Descriptor;
 import org.torproject.descriptor.DescriptorParser;
 import org.torproject.descriptor.DescriptorSourceFactory;
+import org.torproject.descriptor.RelayExtraInfoDescriptor;
+import org.torproject.descriptor.RelayNetworkStatusConsensus;
+import org.torproject.descriptor.RelayNetworkStatusVote;
+import org.torproject.descriptor.RelayServerDescriptor;
+import org.torproject.descriptor.UnparseableDescriptor;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -56,46 +63,22 @@ public class ArchiveWriter extends CollecTorMain {
   private int storedMicrodescriptorsCounter = 0;
 
   private SortedMap<Long, SortedSet<String>> storedConsensuses =
-      new TreeMap<Long, SortedSet<String>>();
+      new TreeMap<>();
   private SortedMap<Long, SortedSet<String>> storedMicrodescConsensuses =
-      new TreeMap<Long, SortedSet<String>>();
-  private SortedMap<Long, Integer> expectedVotes =
-      new TreeMap<Long, Integer>();
-  private SortedMap<Long, SortedMap<String, SortedSet<String>>>
-      storedVotes =
-      new TreeMap<Long, SortedMap<String, SortedSet<String>>>();
+      new TreeMap<>();
+  private SortedMap<Long, Integer> expectedVotes = new TreeMap<>();
+  private SortedMap<Long, SortedMap<String, SortedSet<String>>> storedVotes =
+      new TreeMap<>();
   private SortedMap<Long, Map<String, String>> storedServerDescriptors =
-      new TreeMap<Long, Map<String, String>>();
+      new TreeMap<>();
   private SortedMap<Long, Set<String>> storedExtraInfoDescriptors =
-      new TreeMap<Long, Set<String>>();
-  private SortedMap<Long, Set<String>> storedMicrodescriptors =
-      new TreeMap<Long, Set<String>>();
+      new TreeMap<>();
+  private SortedMap<Long, Set<String>> storedMicrodescriptors = new TreeMap<>();
 
   private File storedServerDescriptorsFile;
   private File storedExtraInfoDescriptorsFile;
   private File storedMicrodescriptorsFile;
 
-  private static final byte[] CONSENSUS_ANNOTATION =
-      "@type network-status-consensus-3 1.0\n".getBytes();
-
-  private static final byte[] MICRODESCCONSENSUS_ANNOTATION =
-      "@type network-status-microdesc-consensus-3 1.0\n".getBytes();
-
-  private static final byte[] VOTE_ANNOTATION =
-      "@type network-status-vote-3 1.0\n".getBytes();
-
-  private static final byte[] CERTIFICATE_ANNOTATION =
-      "@type dir-key-certificate-3 1.0\n".getBytes();
-
-  private static final byte[] SERVER_DESCRIPTOR_ANNOTATION =
-      "@type server-descriptor 1.0\n".getBytes();
-
-  private static final byte[] EXTRA_INFO_ANNOTATION =
-      "@type extra-info 1.0\n".getBytes();
-
-  private static final byte[] MICRODESCRIPTOR_ANNOTATION =
-      "@type microdescriptor 1.0\n".getBytes();
-
   private StringBuilder intermediateStats = new StringBuilder();
 
   private Path recentPath;
@@ -109,6 +92,17 @@ public class ArchiveWriter extends CollecTorMain {
   /** Initialize an archive writer with a given configuration. */
   public ArchiveWriter(Configuration config) throws ConfigurationException {
     super(config);
+    this.mapPathDescriptors.put("recent/relay-descriptors/votes",
+        RelayNetworkStatusVote.class);
+    this.mapPathDescriptors.put("recent/relay-descriptors/consensuses",
+        RelayNetworkStatusConsensus.class);
+    this.mapPathDescriptors.put(
+        "recent/relay-descriptors/microdescs/consensus-microdesc",
+        RelayNetworkStatusConsensus.class);
+    this.mapPathDescriptors.put("recent/relay-descriptors/server-descriptors",
+        RelayServerDescriptor.class);
+    this.mapPathDescriptors.put("recent/relay-descriptors/extra-infos",
+        RelayExtraInfoDescriptor.class);
   }
 
   @Override
@@ -116,6 +110,11 @@ public class ArchiveWriter extends CollecTorMain {
     return "relaydescs";
   }
 
+  @Override
+  protected String syncMarker() {
+    return "Relay";
+  }
+
   @Override
   protected void startProcessing() throws ConfigurationException {
     recentPath = config.getPath(Key.RecentPath);
@@ -129,8 +128,9 @@ public class ArchiveWriter extends CollecTorMain {
     storedMicrodescriptorsFile
         = new File(statsDir, "stored-microdescriptors");
     File statsDirectory = config.getPath(Key.StatsPath).toFile();
-    this.outputDirectory = config.getPath(Key.DirectoryArchivesOutputDirectory)
-        .toString();
+    this.outputDirectory
+        = Paths.get(config.getPath(Key.OutputPath).toString(),
+              RELAY_DESCRIPTORS).toString();
     SimpleDateFormat rsyncCatFormat = new SimpleDateFormat(
         "yyyy-MM-dd-HH-mm-ss");
     rsyncCatFormat.setTimeZone(TimeZone.getTimeZone("UTC"));
@@ -145,31 +145,29 @@ public class ArchiveWriter extends CollecTorMain {
     RelayDescriptorParser rdp = new RelayDescriptorParser(this);
 
     RelayDescriptorDownloader rdd = null;
-    if (config.getBool(Key.DownloadRelayDescriptors)) {
+
+    Set<SourceType> sources = config.getSourceTypeSet(Key.RelaySources);
+    if (sources.contains(SourceType.Remote)) {
       String[] dirSources =
           config.getStringArray(Key.DirectoryAuthoritiesAddresses);
       rdd = new RelayDescriptorDownloader(rdp, dirSources,
           config.getStringArray(Key.DirectoryAuthoritiesFingerprintsForVotes),
-          config.getBool(Key.DownloadCurrentConsensus),
-          config.getBool(Key.DownloadCurrentMicrodescConsensus),
-          config.getBool(Key.DownloadCurrentVotes),
-          config.getBool(Key.DownloadMissingServerDescriptors),
-          config.getBool(Key.DownloadMissingExtraInfoDescriptors),
-          config.getBool(Key.DownloadMissingMicrodescriptors),
+          true, true, true, // download current consensus, microcons, and votes
+          true, true, true, // download missing serverdesc, extrainfo, and micro
           config.getBool(Key.DownloadAllServerDescriptors),
           config.getBool(Key.DownloadAllExtraInfoDescriptors),
           config.getBool(Key.CompressRelayDescriptorDownloads));
       rdp.setRelayDescriptorDownloader(rdd);
     }
-    if (config.getBool(Key.ImportCachedRelayDescriptors)) {
+    if (sources.contains(SourceType.Cache)) {
       new CachedRelayDescriptorReader(rdp,
-          config.getStringArray(Key.CachedRelayDescriptorsDirectories), statsDirectory);
+          config.getStringArray(Key.RelayCacheOrigins), statsDirectory);
       this.intermediateStats("importing relay descriptors from local "
           + "Tor data directories");
     }
-    if (config.getBool(Key.ImportDirectoryArchives)) {
+    if (sources.contains(SourceType.Local)) {
       new ArchiveReader(rdp,
-                        config.getPath(Key.DirectoryArchivesDirectory).toFile(),
+          config.getPath(Key.RelayLocalOrigins).toFile(),
           statsDirectory,
           config.getBool(Key.KeepDirectoryArchiveImportHistory));
       this.intermediateStats("importing relay descriptors from local "
@@ -191,10 +189,22 @@ public class ArchiveWriter extends CollecTorMain {
 
     this.saveDescriptorDigests();
 
-    new ReferenceChecker(recentPath.toFile(),
+    new ReferenceChecker(Paths.get(recentPathName, RELAY_DESCRIPTORS).toFile(),
         new File(statsDir, "references"),
         new File(statsDir, "references-history")).check();
     CollecTorMain.checkAvailableSpace(recentPath);
+    cleanUp();
+  }
+
+  private void cleanUp() {
+    this.expectedVotes.clear();
+    this.intermediateStats = new StringBuilder();
+    this.storedConsensuses.clear();
+    this.storedMicrodescConsensuses.clear();
+    this.storedVotes.clear();
+    this.storedServerDescriptors.clear();
+    this.storedExtraInfoDescriptors.clear();
+    this.storedMicrodescriptors.clear();
   }
 
   private void loadDescriptorDigests() {
@@ -285,11 +295,7 @@ public class ArchiveWriter extends CollecTorMain {
         }
         br.close();
       }
-    } catch (ParseException e) {
-      logger.warn("Could not load descriptor "
-          + "digests.  We might not be able to correctly check "
-          + "descriptors for completeness.", e);
-    } catch (IOException e) {
+    } catch (IOException | ParseException e) {
       logger.warn("Could not load descriptor "
           + "digests.  We might not be able to correctly check "
           + "descriptors for completeness.", e);
@@ -326,18 +332,17 @@ public class ArchiveWriter extends CollecTorMain {
     SimpleDateFormat dateTimeFormat =
         new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
     dateTimeFormat.setTimeZone(TimeZone.getTimeZone("UTC"));
-    Map<String, String> knownServerDescriptors =
-        new HashMap<String, String>();
+    Map<String, String> knownServerDescriptors = new HashMap<>();
     for (Map<String, String> descriptors :
         this.storedServerDescriptors.values()) {
       knownServerDescriptors.putAll(descriptors);
     }
-    Set<String> knownExtraInfoDescriptors = new HashSet<String>();
+    Set<String> knownExtraInfoDescriptors = new HashSet<>();
     for (Set<String> descriptors :
         this.storedExtraInfoDescriptors.values()) {
       knownExtraInfoDescriptors.addAll(descriptors);
     }
-    Set<String> knownMicrodescriptors = new HashSet<String>();
+    Set<String> knownMicrodescriptors = new HashSet<>();
     for (Set<String> descriptors : this.storedMicrodescriptors.values()) {
       knownMicrodescriptors.addAll(descriptors);
     }
@@ -556,7 +561,7 @@ public class ArchiveWriter extends CollecTorMain {
     long cutOffMillis = System.currentTimeMillis()
         - 3L * 24L * 60L * 60L * 1000L;
     long cutOffMicroMillis = cutOffMillis - 27L * 24L * 60L * 60L * 1000L;
-    Stack<File> allFiles = new Stack<File>();
+    Stack<File> allFiles = new Stack<>();
     allFiles.add(new File(recentPathName, RELAY_DESCRIPTORS));
     while (!allFiles.isEmpty()) {
       File file = allFiles.pop();
@@ -641,7 +646,7 @@ public class ArchiveWriter extends CollecTorMain {
     File rsyncFile = Paths.get(recentPathName, RELAY_DESCRIPTORS,
         "consensuses", tarballFile.getName()).toFile();
     File[] outputFiles = new File[] { tarballFile, rsyncFile };
-    if (this.store(CONSENSUS_ANNOTATION, data, outputFiles, null)) {
+    if (this.store(Annotation.Consensus.bytes(), data, outputFiles, null)) {
       this.storedConsensusesCounter++;
     }
     if (!tarballFileExistedBefore
@@ -663,12 +668,13 @@ public class ArchiveWriter extends CollecTorMain {
     dayDirectoryFileFormat.setTimeZone(TimeZone.getTimeZone("UTC"));
     File tarballFile = Paths.get(this.outputDirectory, MICRODESC,
         yearMonthDirectoryFormat.format(validAfter), CONSENSUS_MICRODESC,
-        dayDirectoryFileFormat.format(validAfter) + "-consensus-microdesc").toFile();
+        dayDirectoryFileFormat.format(validAfter)
+        + "-consensus-microdesc").toFile();
     boolean tarballFileExistedBefore = tarballFile.exists();
     File rsyncFile = Paths.get(recentPathName, RELAY_DESCRIPTORS, MICRODESCS,
         CONSENSUS_MICRODESC, tarballFile.getName()).toFile();
     File[] outputFiles = new File[] { tarballFile, rsyncFile };
-    if (this.store(MICRODESCCONSENSUS_ANNOTATION, data, outputFiles,
+    if (this.store(Annotation.MicroConsensus.bytes(), data, outputFiles,
         null)) {
       this.storedMicrodescConsensusesCounter++;
     }
@@ -694,7 +700,7 @@ public class ArchiveWriter extends CollecTorMain {
     File rsyncFile = Paths.get(recentPathName, RELAY_DESCRIPTORS, "votes",
         tarballFile.getName()).toFile();
     File[] outputFiles = new File[] { tarballFile, rsyncFile };
-    if (this.store(VOTE_ANNOTATION, data, outputFiles, null)) {
+    if (this.store(Annotation.Vote.bytes(), data, outputFiles, null)) {
       this.storedVotesCounter++;
     }
     if (!tarballFileExistedBefore
@@ -717,7 +723,7 @@ public class ArchiveWriter extends CollecTorMain {
     File tarballFile = Paths.get(this.outputDirectory, "certs",
         fingerprint + "-" + printFormat.format(new Date(published))).toFile();
     File[] outputFiles = new File[] { tarballFile };
-    if (this.store(CERTIFICATE_ANNOTATION, data, outputFiles, null)) {
+    if (this.store(Annotation.Cert.bytes(), data, outputFiles, null)) {
       this.storedCertsCounter++;
     }
   }
@@ -737,7 +743,7 @@ public class ArchiveWriter extends CollecTorMain {
         this.rsyncCatString + "-server-descriptors.tmp").toFile();
     File[] outputFiles = new File[] { tarballFile, rsyncCatFile };
     boolean[] append = new boolean[] { false, true };
-    if (this.store(SERVER_DESCRIPTOR_ANNOTATION, data, outputFiles,
+    if (this.store(Annotation.Server.bytes(), data, outputFiles,
         append)) {
       this.storedServerDescriptorsCounter++;
     }
@@ -767,7 +773,7 @@ public class ArchiveWriter extends CollecTorMain {
         "extra-infos", this.rsyncCatString + "-extra-infos.tmp").toFile();
     File[] outputFiles = new File[] { tarballFile, rsyncCatFile };
     boolean[] append = new boolean[] { false, true };
-    if (this.store(EXTRA_INFO_ANNOTATION, data, outputFiles, append)) {
+    if (this.store(Annotation.ExtraInfo.bytes(), data, outputFiles, append)) {
       this.storedExtraInfoDescriptorsCounter++;
     }
     if (!tarballFileExistedBefore
@@ -802,7 +808,7 @@ public class ArchiveWriter extends CollecTorMain {
         MICRODESCS, MICRO, this.rsyncCatString + "-micro.tmp").toFile();
     File[] outputFiles = new File[] { tarballFile, rsyncCatFile };
     boolean[] append = new boolean[] { false, true };
-    if (this.store(MICRODESCRIPTOR_ANNOTATION, data, outputFiles,
+    if (this.store(Annotation.Microdescriptor.bytes(), data, outputFiles,
         append)) {
       this.storedMicrodescriptorsCounter++;
     }
@@ -819,16 +825,17 @@ public class ArchiveWriter extends CollecTorMain {
 
   private boolean store(byte[] typeAnnotation, byte[] data,
       File[] outputFiles, boolean[] append) {
-    try {
-      logger.trace("Storing " + outputFiles[0]);
-      if (this.descriptorParser.parseDescriptors(data,
-          outputFiles[0].getName()).size() != 1) {
-        logger.info("Relay descriptor file " + outputFiles[0]
-            + " doesn't contain exactly one descriptor.  Storing anyway.");
+    logger.trace("Storing " + outputFiles[0]);
+    int parseableDescriptors = 0;
+    for (Descriptor descriptor : this.descriptorParser.parseDescriptors(data,
+        null, outputFiles[0].getName())) {
+      if (!(descriptor instanceof UnparseableDescriptor)) {
+        parseableDescriptors++;
       }
-    } catch (DescriptorParseException e) {
-      this.logger.info("Could not parse relay descriptor "
-          + outputFiles[0] + " before storing it to disk.  Storing anyway.", e);
+    }
+    if (parseableDescriptors != 1) {
+      logger.info("Relay descriptor file " + outputFiles[0]
+          + " doesn't contain exactly one descriptor.  Storing anyway.");
     }
     try {
       for (int i = 0; i < outputFiles.length; i++) {
