@@ -1,4 +1,4 @@
-/* Copyright 2010--2016 The Tor Project
+/* Copyright 2010--2018 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.collector.relaydescs;
@@ -53,7 +53,8 @@ public class RelayDescriptorDownloader {
    * - "consensus-microdesc,&lt;validafter&gt;,&lt;parsed&gt;",
    * - "vote,&lt;validafter&gt;,&lt;fingerprint&gt;,&lt;parsed&gt;",
    * - "server,&lt;published&gt;,&lt;relayid&gt;,&lt;descid&gt;,&lt;parsed&gt;",
-   * - "extra,&lt;published&gt;,&lt;relayid&gt;,&lt;descid&gt;,&lt;parsed&gt;", or
+   * - "extra,&lt;published&gt;,&lt;relayid&gt;,&lt;descid&gt;,&lt;parsed&gt;",
+   *   or
    * - "micro,&lt;validafter&gt;,&lt;relayid&gt;,&lt;descid&gt;,&lt;parsed&gt;".
    * </p>
    */
@@ -69,9 +70,9 @@ public class RelayDescriptorDownloader {
 
   /**
    * Map from base64 microdescriptor digests to keys in missingDescriptors
-   * ("micro,&lt;validafter&gt;,&lt;relayid&gt;,&lt;descid&gt;"). We need this map, because
-   * we can't learn &lt;validafter&gt; or &lt;relayid&gt; from parsing
-   * microdescriptors, but we need to know &lt;validafter&gt; to store
+   * ("micro,&lt;validafter&gt;,&lt;relayid&gt;,&lt;descid&gt;"). We need this
+   * map, because we can't learn &lt;validafter&gt; or &lt;relayid&gt; from
+   * parsing microdescriptors, but we need to know &lt;validafter&gt; to store
    * microdescriptors to disk and both &lt;validafter&gt; and &lt;relayid&gt; to
    * remove microdescriptors from the missing list. There are potentially
    * many matching keys in missingDescriptors for the same microdescriptor
@@ -336,9 +337,9 @@ public class RelayDescriptorDownloader {
     /* Read list of missing descriptors from disk and memorize those that
      * we are interested in and that are likely to be found on the
      * directory authorities. */
-    this.missingDescriptors = new TreeMap<String, String>();
-    this.microdescriptorKeys = new HashMap<String, Set<String>>();
-    this.missingMicrodescriptors = new HashSet<String>();
+    this.missingDescriptors = new TreeMap<>();
+    this.microdescriptorKeys = new HashMap<>();
+    this.missingMicrodescriptors = new HashSet<>();
     this.missingDescriptorsFile = new File(
         "stats/missing-relay-descriptors");
     if (this.missingDescriptorsFile.exists()) {
@@ -412,7 +413,7 @@ public class RelayDescriptorDownloader {
 
     /* Read list of directory authorities and when we last downloaded all
      * server and extra-info descriptors from them. */
-    this.lastDownloadedAllDescriptors = new HashMap<String, String>();
+    this.lastDownloadedAllDescriptors = new HashMap<>();
     this.lastDownloadedAllDescriptorsFile = new File(
         "stats/last-downloaded-all-descriptors");
     if (this.lastDownloadedAllDescriptorsFile.exists()) {
@@ -450,7 +451,7 @@ public class RelayDescriptorDownloader {
 
     /* Make a list of at most two directory authorities that we want to
      * download all server and extra-info descriptors from. */
-    this.downloadAllDescriptorsFromAuthorities = new HashSet<String>();
+    this.downloadAllDescriptorsFromAuthorities = new HashSet<>();
     for (String authority : this.authorities) {
       if (!this.lastDownloadedAllDescriptors.containsKey(authority)
           || this.lastDownloadedAllDescriptors.get(authority).compareTo(
@@ -463,7 +464,7 @@ public class RelayDescriptorDownloader {
     }
 
     /* Prepare statistics on this execution. */
-    this.requestsByAuthority = new HashMap<String, Integer>();
+    this.requestsByAuthority = new HashMap<>();
     for (String authority : this.authorities) {
       this.requestsByAuthority.put(authority, 0);
     }
@@ -508,10 +509,9 @@ public class RelayDescriptorDownloader {
   }
 
   /**
-   * We have parsed a microdesc consensus. Take this microdesc consensus
-   * off the missing list and add the <code>microdescriptors</code> which
-   * are in the format "&lt;validafter&gt;,&lt;relayid&gt;,&lt;descid&gt;" to that
-   * list.
+   * We have parsed a microdesc consensus. Take this microdesc consensus off the
+   * missing list and add the <code>microdescriptors</code> which are in the
+   * format "&lt;validafter&gt;,&lt;relayid&gt;,&lt;descid&gt;" to that list.
    */
   public void haveParsedMicrodescConsensus(String validAfter,
       Set<String> microdescriptors) {
@@ -720,7 +720,7 @@ public class RelayDescriptorDownloader {
         /* Next, try to download current votes that we're missing. */
         if (downloadCurrentVotes) {
           String voteKeyPrefix = "vote," + this.currentValidAfter;
-          SortedSet<String> fingerprints = new TreeSet<String>();
+          SortedSet<String> fingerprints = new TreeSet<>();
           for (Map.Entry<String, String> e :
               this.missingDescriptors.entrySet()) {
             if (e.getValue().equals("NA")
@@ -775,8 +775,7 @@ public class RelayDescriptorDownloader {
              * and combine the descriptor identifiers to a URL of up to
              * 96 server or extra-info descriptors or 92 microdescriptors
              * that we can download at once. */
-            SortedSet<String> descriptorIdentifiers =
-                new TreeSet<String>();
+            SortedSet<String> descriptorIdentifiers = new TreeSet<>();
             for (Map.Entry<String, String> e :
                 this.missingDescriptors.entrySet()) {
               if (e.getValue().equals("NA")
@@ -860,28 +859,29 @@ public class RelayDescriptorDownloader {
     /* TODO Disable compressed downloads for extra-info descriptors,
      * because zlib decompression doesn't work correctly. Figure out why
      * this is and fix it. */
-    String fullUrl = "http://" + authority + resource
-        + (this.downloadCompressed && !resource.startsWith("/tor/extra/")
-        ? ".z" : "");
+    boolean isCompressed = this.downloadCompressed
+        && !resource.startsWith("/tor/extra/");
+    String fullUrl
+        = "http://" + authority + resource + (isCompressed ? ".z" : "");
     URL url = new URL(fullUrl);
     HttpURLConnection huc = (HttpURLConnection) url.openConnection();
     huc.setRequestMethod("GET");
+    huc.setReadTimeout(5000);
     huc.connect();
     int response = huc.getResponseCode();
     if (response == 200) {
-      BufferedInputStream in = this.downloadCompressed
-          && !resource.startsWith("/tor/extra/")
-          ? new BufferedInputStream(new InflaterInputStream(
+      try (BufferedInputStream in
+          = isCompressed ? new BufferedInputStream(new InflaterInputStream(
           huc.getInputStream()))
-          : new BufferedInputStream(huc.getInputStream());
-      ByteArrayOutputStream baos = new ByteArrayOutputStream();
-      int len;
-      byte[] data = new byte[1024];
-      while ((len = in.read(data, 0, 1024)) >= 0) {
-        baos.write(data, 0, len);
+          : new BufferedInputStream(huc.getInputStream())) {
+        ByteArrayOutputStream baos = new ByteArrayOutputStream();
+        int len;
+        byte[] data = new byte[1024];
+        while ((len = in.read(data, 0, 1024)) >= 0) {
+          baos.write(data, 0, len);
+        }
+        allData = baos.toByteArray();
       }
-      in.close();
-      allData = baos.toByteArray();
     }
     logger.debug("Downloaded " + fullUrl + " -> " + response + " ("
         + (allData == null ? 0 : allData.length) + " bytes)");
