@@ -1,4 +1,4 @@
-/* Copyright 2016--2017 The Tor Project
+/* Copyright 2016--2018 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.collector.sync;
@@ -28,6 +28,7 @@ import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.List;
+import java.util.stream.Collectors;
 
 @RunWith(Parameterized.class)
 public class SyncPersistenceTest {
@@ -43,6 +44,32 @@ public class SyncPersistenceTest {
          Integer.valueOf(1), // expected recent count of descs files
          Integer.valueOf(1)}, // expected output count of descs files
 
+        {"torperf/op-nl-1048576-2017-04-11.tpf",
+         new String[]{"torperf/2017/04/11/op-nl-1048576-2017-04-11.tpf"},
+         "op-nl-1048576-2017-04-11.tpf",
+         Integer.valueOf(1),
+         Integer.valueOf(1)},
+
+        {"webstats/archive.torproject.org_"
+             + "archeotrichon.torproject.org_access.log_20151007.xz",
+         new String[]{"webstats/archive.torproject.org/2015/10/07/"
+             + "archive.torproject.org_archeotrichon.torproject.org"
+             + "_access.log_20151007.xz"},
+         "archeotrichon.torproject.org/archive.torproject.org_"
+             + "archeotrichon.torproject.org_access.log_20151007.xz",
+         Integer.valueOf(1),
+         Integer.valueOf(1)},
+
+        {"webstats/metrics.torproject.org_"
+             + "meronense.torproject.org_access.log_20170531.xz",
+         new String[]{"webstats/metrics.torproject.org/2017/05/31/"
+             + "metrics.torproject.org_meronense.torproject.org"
+             + "_access.log_20170531.xz"},
+         "meronense.torproject.org/metrics.torproject.org_"
+             + "meronense.torproject.org_access.log_20170531.gz",
+         Integer.valueOf(1),
+         Integer.valueOf(1)},
+
         {"relay-descriptors/server-descriptors/"
              + "2016-10-05-19-06-17-server-descriptors",
          new String[]{"relay-descriptors/server-descriptor/2016/10/e/3/"
@@ -193,6 +220,7 @@ public class SyncPersistenceTest {
   private int outCount;
   private int recentCount;
   private String filename;
+  private File fileForName;
   private File recent;
   private File output;
   private String recentName;
@@ -205,6 +233,7 @@ public class SyncPersistenceTest {
     this.expectedRecentDir = subRecent;
     this.expectedOutputDir = subOutput;
     this.filename = fn;
+    this.fileForName = new File(fn);
     this.outCount = outCount;
     this.recentCount = recentCount;
   }
@@ -220,8 +249,9 @@ public class SyncPersistenceTest {
     makeTemporaryFolders();
     DescriptorParser dp = DescriptorSourceFactory.createDescriptorParser();
     SyncPersistence persist = new SyncPersistence(conf);
-    persist.storeDescs(dp.parseDescriptors(bytesFromResource(), filename),
-        filename, 1475694377000L);
+    persist.storeDescs(dp.parseDescriptors(bytesFromResource(),
+        fileForName, filename), 1475694377000L);
+    persist.cleanDirectory();
     List<File> recentList = new ArrayList<>();
     Files.walkFileTree(recent.toPath(), new FileCollector(recentList));
     String dataUsed = "data used: " + expectedRecentDir + ", " + filename
@@ -237,8 +267,9 @@ public class SyncPersistenceTest {
     makeTemporaryFolders();
     DescriptorParser dp = DescriptorSourceFactory.createDescriptorParser();
     SyncPersistence persist = new SyncPersistence(conf);
-    persist.storeDescs(dp.parseDescriptors(bytesFromResource(), filename),
-        filename, 1475694377000L);
+    persist.storeDescs(dp.parseDescriptors(bytesFromResource(),
+        fileForName, filename), 1475694377000L);
+    persist.cleanDirectory();
     List<File> recentList = new ArrayList<>();
     List<File> outputList = new ArrayList<>();
     Files.walkFileTree(output.toPath(), new FileCollector(outputList));
@@ -256,20 +287,25 @@ public class SyncPersistenceTest {
 
   @Test()
   public void testRecentFileContent() throws Exception {
+    if (this.filename.contains(".log")) {
+      return; // Skip this test, because logs are compressed and sanitized.
+    }
     conf = new Configuration();
     makeTemporaryFolders();
     DescriptorParser dp = DescriptorSourceFactory.createDescriptorParser();
     SyncPersistence persist = new SyncPersistence(conf);
-    persist.storeDescs(dp.parseDescriptors(bytesFromResource(), filename),
-        filename, 1475694377000L);
+    persist.storeDescs(dp.parseDescriptors(bytesFromResource(),
+        fileForName, filename), 1475694377000L);
+    persist.cleanDirectory();
     List<File> recentList = new ArrayList<>();
     Files.walkFileTree(recent.toPath(), new FileCollector(recentList));
     assertEquals(recentCount, recentList.size());
     List<String> content = Files.readAllLines(recentList.get(0).toPath(),
         StandardCharsets.UTF_8);
     List<String> expContent = linesFromResource(filename);
-    assertEquals(expContent.size(), content.size());
     int contentSize = content.size();
+    assertEquals("Number of lines incorrect for file '" + filename + "': "
+        + content, expContent.size(), contentSize);
     for (String line : expContent) {
       assertTrue("Couln't remove " + line + " from " + recentList.get(0),
           content.remove(line));
@@ -280,21 +316,24 @@ public class SyncPersistenceTest {
 
   @Test()
   public void testOutFileContent() throws Exception {
+    if (this.filename.contains(".log")) {
+      return; // Skip this test, because logs are compressed and sanitized.
+    }
     conf = new Configuration();
     makeTemporaryFolders();
     DescriptorParser dp = DescriptorSourceFactory.createDescriptorParser();
     SyncPersistence persist = new SyncPersistence(conf);
-    persist.storeDescs(dp.parseDescriptors(bytesFromResource(), filename),
-        filename, 1475694377000L);
+    persist.storeDescs(dp.parseDescriptors(bytesFromResource(),
+        fileForName, filename), 1475694377000L);
+    persist.cleanDirectory();
     List<File> outputList = new ArrayList<>();
     Files.walkFileTree(output.toPath(), new FileCollector(outputList));
     assertEquals(outCount, outputList.size());
     List<String> expContent = linesFromResource(filename);
     int expContentSize = expContent.size();
     for (File file : outputList) {
-      List<String> content = Files.readAllLines(file.toPath(),
-          StandardCharsets.UTF_8);
-      for (String line : content) {
+      for (String line : Files.readAllLines(file.toPath(),
+          StandardCharsets.UTF_8)) {
         assertTrue("Couldn't remove " + line + ".", expContent.remove(line));
         assertEquals(--expContentSize, expContent.size());
       }
@@ -312,49 +351,25 @@ public class SyncPersistenceTest {
   }
 
   private byte[] bytesFromResource() throws Exception {
-    StringBuilder sb = new StringBuilder();
-    BufferedReader br = new BufferedReader(new InputStreamReader(getClass()
-        .getClassLoader().getResourceAsStream(filename)));
-    String line = br.readLine();
-    while (null != line) {
-      sb.append(line).append('\n');
-      line = br.readLine();
-    }
-    return sb.toString().getBytes();
+    return Files.readAllBytes((new File(getClass()
+        .getClassLoader().getResource(filename).toURI())).toPath());
   }
 
   private String stringFromResource() throws Exception {
-    StringBuilder sb = new StringBuilder();
     BufferedReader br = new BufferedReader(new InputStreamReader(getClass()
         .getClassLoader().getResourceAsStream(filename)));
-    String line = br.readLine();
-    while (null != line) {
-      sb.append(line).append('\n');
-      line = br.readLine();
-    }
-    return sb.toString();
+    return br.lines().collect(Collectors.joining("\n", "", "\n"));
   }
 
   private String stringFromFile(File file) throws Exception {
-    StringBuilder sb = new StringBuilder();
-    List<String> lines = Files.readAllLines(file.toPath(),
-        StandardCharsets.UTF_8);
-    for (String line : lines) {
-      sb.append(line).append('\n');
-    }
-    return sb.toString();
+    return Files.lines(file.toPath(), StandardCharsets.UTF_8)
+        .collect(Collectors.joining("\n", "", "\n"));
   }
 
   private List<String> linesFromResource(String filename) throws Exception {
-    List<String> res = new ArrayList<>();
     BufferedReader br = new BufferedReader(new InputStreamReader(getClass()
         .getClassLoader().getResourceAsStream(filename)));
-    String line = br.readLine();
-    while (null != line) {
-      res.add(line);
-      line = br.readLine();
-    }
-    return res;
+    return br.lines().collect(Collectors.toList());
   }
 
 }
